@@ -1,10 +1,10 @@
-__version__ = "0.1.21"
+__version__ = "0.1.22"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(detached from v0.1.21)'
+__git_branch__ = '(detached from v0.1.22)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = 'bc23a512ff0c77395b0e6300e0ab0be67ef2739a'
-__git_head_subject__ = 'Finished release v0.1.21.'
+__git_head_hash__ = 'fd26d84b6565349f205cf870aecb46010f44d805'
+__git_head_subject__ = "skip test that doesn't work"
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
